@@ -243,6 +243,8 @@ static const struct key_mapping key_mappings[] = {
 	{ "ShiftDel",	KEY_SDC },
 	{ "ShiftHome",	KEY_SHOME },
 	{ "ShiftEnd",	KEY_SEND },
+	{ "SingleQuote", '\'' },
+	{ "DoubleQuote", '"' },
 };
 
 static const struct key_mapping *
@@ -314,14 +316,11 @@ get_key_value(const char **name_ptr, struct key *key)
 			if (!mapping)
 				return error("Unknown key mapping: %.*s", len, start);
 
-			if (mapping->value == ' ')
-				return parse_key_value(key, name_ptr, 0, " ", end);
+			if (strchr(" #<'\"", mapping->value)) {
+				const char replacement[] = { mapping->value, 0 };
 
-			if (mapping->value == '#')
-				return parse_key_value(key, name_ptr, 0, "#", end);
-
-			if (mapping->value == '<')
-				return parse_key_value(key, name_ptr, 0, "<", end);
+				return parse_key_value(key, name_ptr, 0, replacement, end);
+			}
 
 			*name_ptr = end + 1;
 			key->data.value = mapping->value;
@@ -450,7 +449,7 @@ static size_t run_requests;
 
 DEFINE_ALLOCATOR(realloc_run_requests, struct run_request, 8)
 
-#define COMMAND_FLAGS ":!?@<+"
+#define COMMAND_FLAGS ":!?@<+>"
 
 enum status_code
 parse_run_request_flags(struct run_request_flags *flags, const char **argv)
@@ -474,6 +473,8 @@ parse_run_request_flags(struct run_request_flags *flags, const char **argv)
 			flags->exit = 1;
 		} else if (*argv[0] == '+') {
 			flags->echo = 1;
+		} else if (*argv[0] == '>') {
+			flags->quick = 1;
 		} else if (*argv[0] != '!') {
 			break;
 		}
@@ -536,6 +537,8 @@ format_run_request_flags(const struct run_request *req)
 		flags[flagspos++] = '<';
 	if (req->flags.echo)
 		flags[flagspos++] = '+';
+	if (req->flags.quick)
+		flags[flagspos++] = '>';
 	if (flagspos > 1)
 		flags[flagspos++] = 0;
 
