@@ -54,6 +54,12 @@
 #include <readline/readline.h>
 #endif /* HAVE_READLINE */
 
+#if defined HAVE_PCRE2
+#include <pcre2.h>
+#elif defined HAVE_PCRE
+#include <pcre.h>
+#endif
+
 static bool
 forward_request_to_child(struct view *child, enum request request)
 {
@@ -104,6 +110,7 @@ view_request(struct view *view, enum request request)
 	_('C', "local change display",		"show-changes"), \
 	_('X', "commit ID display",		"id"), \
 	_('%', "file filtering",		"file-filter"), \
+	_('^', "revision filtering",		"rev-filter"), \
 	_('$', "commit title overflow display",	"commit-title-overflow"), \
 	_('d', "untracked directory info",	"status-show-untracked-dirs"), \
 	_('|', "view split",			"vertical-split"), \
@@ -542,6 +549,9 @@ parse_options(int argc, const char *argv[], bool pager_mode)
 				seen_dashdash = true;
 
 			} else if (!strcmp(opt, "-v") || !strcmp(opt, "--version")) {
+#if defined HAVE_PCRE2
+				char pcre2_version[64];
+#endif
 				printf("tig version %s\n", TIG_VERSION);
 #ifdef NCURSES_VERSION
 				printf("%s version %s.%d\n",
@@ -554,6 +564,12 @@ parse_options(int argc, const char *argv[], bool pager_mode)
 #endif
 #ifdef HAVE_READLINE
 				printf("readline version %s\n", rl_library_version);
+#endif
+#if defined HAVE_PCRE2
+				pcre2_config(PCRE2_CONFIG_VERSION, pcre2_version);
+				printf("PCRE2 version %s\n", pcre2_version);
+#elif defined HAVE_PCRE
+				printf("PCRE version %s\n", pcre_version());
 #endif
 				exit(EXIT_SUCCESS);
 
