@@ -67,7 +67,7 @@ git checkout release
 HEAD="$(git rev-parse release)"
 git merge --ff master
 if test -n "$(git rev-list -1 release ^$HEAD)"; then
-	make distclean doc-man doc-html sysconfdir=++SYSCONFDIR++
+	make veryclean doc-man doc-html sysconfdir=++SYSCONFDIR++
 	git commit -a -m "Update for version $TAG"
 fi
 
